@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/macperl/perl/macos/ext/Mac/Carbon/Carbon.h,v 1.13 2005/05/04 05:43:29 pudge Exp $
+/* $Header: /cvsroot/macperl/perl/macos/ext/Mac/Carbon/Carbon.h,v 1.14 2006/06/20 01:39:17 pudge Exp $
  *
  *    Copyright (c) 2002 Matthias Neeracher, Chris Nandor
  *
@@ -6,6 +6,9 @@
  *    as specified in the README file.
  *
  * $Log: Carbon.h,v $
+ * Revision 1.14  2006/06/20 01:39:17  pudge
+ * Loads of fixes, mostly for Intel port
+ *
  * Revision 1.13  2005/05/04 05:43:29  pudge
  * Change cast for errno
  *
@@ -107,18 +110,36 @@ static bool ReadHex(const char * path, int bytes, char * result)
 {
 	char hexbyte[3];
 	hexbyte[2] = 0;
-	while (bytes--) {
+	int i, j;
+
+	for (i = 0; i < bytes; i++) {
 		hexbyte[0] = *path++; hexbyte[1] = *path++;
 		if (isxdigit(hexbyte[0]) && isxdigit(hexbyte[1])) {
-			*result++ = (char) strtol(hexbyte, nil, 16);
+#if __BIG_ENDIAN__
+			j = i;
+#elif __LITTLE_ENDIAN__
+			j = (bytes-1)-i;
+#endif
+			*(result+j) = (char) strtol(hexbyte, nil, 16);
 		} else {
 			return false;
 		}
 	}
+
+	result += 4;
+
 	return true;
 }
 
 
+/* Intel expects OSTypes in "reverse order" */
+static void ConvertFourCharCode(OSType dataType, char * dataPtr)
+{
+	if (dataType == typeEnumerated || dataType == typeType || dataType == typeProperty || dataType == typeKeyword || dataType == typeApplSignature) {
+		*(long *)dataPtr = ntohl(*(long*)dataPtr);
+	}
+}
+
 /*   Mac OS and Unix have different epochs (see perlport).
  *   Mac OS is seconds since midnight Jan 1 1904 local time,
  *   Unix is   seconds since midnight Jan 1 1970 UTC.
@@ -152,7 +173,6 @@ static UInt32 SecondsUnix2Mac(UInt32 unixseconds)
 	return macseconds;
 }
 
-
 /*   GUSI replacement routines.  Currently, we use FS* functions
  *   to convert FSRefs to and from paths and FSSpecs, which works
  *   nicely, except that it only works for existing files.
